/// The load resistance on the board
#define RLOAD 10.0
/// Calibration resistance at atmospheric CO2 level
#define RZERO 1212.78
/// Parameters for calculating ppm of CO2 from sensor resistance
#define PARA 116.6020682
#define PARB 2.769034857

/// Parameters to model temperature and humidity dependence
#define CORA 0.00035
#define CORB 0.02718
#define CORC 1.39538
#define CORD 0.0018

/// Atmospheric CO2 level for calibration purposes
#define ATMOCO2 400



/// Calibration resistance at atmospheric CO2 level
#define MQ135PIN 2

float airthreshold[3] =
{
  400, 400, 800
};

//-------------------------------------------------------------------------------------------MQ-135(co2)^

#include <dht.h>

dht DHT;

#define DHT11_PIN 7

//-------------------------------------------------------------------------------------------DHT11^
//-------------------------------------------------------------------------------------------BMP180

#include <Adafruit_BMP085.h>

/***************************************************
  This is an example for the BMP085 Barometric Pressure & Temp Sensor
  Designed specifically to work with the Adafruit BMP085 Breakout
  ----> https://www.adafruit.com/products/391
  These displays use I2C to communicate, 2 pins are required to
  interface
  Adafruit invests time and resources providing this open source code,
  please support Adafruit and open-source hardware by purchasing
  products from Adafruit!
  Written by Limor Fried/Ladyada for Adafruit Industries.
  BSD license, all text above must be included in any redistribution
 ****************************************************/

// Connect VCC of the BMP085 sensor to 3.3V (NOT 5.0V!)
// Connect GND to Ground
// Connect SCL to i2c clock - on '168/'328 Arduino Uno/Duemilanove/etc thats Analog 5
// Connect SDA to i2c data - on '168/'328 Arduino Uno/Duemilanove/etc thats Analog 4
// EOC is not used, it signifies an end of conversion
// XCLR is a reset pin, also not used here

Adafruit_BMP085 bmp;
//-------------------------------------------------------------------------------------------BMP180^
//-------------------------------------------------------------------------------------------MQ7

//-------------------------------------------------------------------------------------------MQ7^
long delaytijd;

void setup() {
  Serial.begin( 9600 );    // 9600 is the default baud rate for the serial Bluetooth module
  if (!bmp.begin()) {
    Serial.println("Could not find a valid BMP085 sensor, check wiring!");
  }
  //WARNING! Each sensor is different!

}

void loop() {
  //if (Serial.available() > 0) {

    //Serial.read();
  //}
  //read_MQ7();
  if (millis() - delaytijd > 2000) {
    read_MQ135();
    read_BMP180();
    read_dht11();
    delaytijd = millis();
  }
}


void read_BMP180() {
  Serial.print("Temperature = ");
  Serial.print(bmp.readTemperature());
  Serial.println(" *C");

  Serial.print("Pressure = ");
  Serial.print(bmp.readPressure());
  Serial.println(" Pa");

}
void read_MQ135() {
  float ppm = getPPM();
  Serial.print("CO2: ");
  Serial.print(ppm);
  Serial.println("ppm ");

}

void read_dht11() {
  int chk = DHT.read11(DHT11_PIN);
  Serial.println(DHT.temperature);
  Serial.println(DHT.humidity);
}

//--------------------------------------------------------------------------------------------MQ135

////////////MQ Code///////////////
/**************************************************************************/
/*!
  @file     MQ135.cpp
  @author   G.Krocker (Mad Frog Labs)
  @license  GNU GPLv3

  First version of an Arduino Library for the MQ135 gas sensor
  TODO: Review the correction factor calculation. This currently relies on
  the datasheet but the information there seems to be wrong.

  @section  HISTORY

  v1.0 - First release
*/


/**************************************************************************/
/*!
  @brief  Get the correction factor to correct for temperature and humidity

  @param[in] t  The ambient air temperature
  @param[in] h  The relative humidity

  @return The calculated correction factor
*/
/**************************************************************************/
float getCorrectionFactor(float t, float h) {
  return CORA * t * t - CORB * t + CORC - (h - 33.) * CORD;
}

/**************************************************************************/
/*!
  @brief  Get the resistance of the sensor, ie. the measurement value

  @return The sensor resistance in kOhm
*/
/**************************************************************************/
float getResistance() {
  int val = analogRead(MQ135PIN);
  return ((1023. / (float)val) * 5. - 1.) * RLOAD;
}

/**************************************************************************/
/*!
  @brief  Get the resistance of the sensor, ie. the measurement value corrected
        for temp/hum

  @param[in] t  The ambient air temperature
  @param[in] h  The relative humidity

  @return The corrected sensor resistance kOhm
*/
/**************************************************************************/
float getCorrectedResistance(float t, float h) {
  return getResistance() / getCorrectionFactor(t, h);
}

/**************************************************************************/
/*!
  @brief  Get the ppm of CO2 sensed (assuming only CO2 in the air)

  @return The ppm of CO2 in the air
*/
/**************************************************************************/
float getPPM() {
  return PARA * pow((getResistance() / RZERO), -PARB);
}

/**************************************************************************/
/*!
  @brief  Get the ppm of CO2 sensed (assuming only CO2 in the air), corrected
        for temp/hum

  @param[in] t  The ambient air temperature
  @param[in] h  The relative humidity

  @return The ppm of CO2 in the air
*/
/**************************************************************************/
float getCorrectedPPM(float t, float h) {
  return PARA * pow((getCorrectedResistance(t, h) / RZERO), -PARB);
}

/**************************************************************************/
/*!
  @brief  Get the resistance RZero of the sensor for calibration purposes

  @return The sensor resistance RZero in kOhm
*/
/**************************************************************************/
float getRZero() {
  return getResistance() * pow((ATMOCO2 / PARA), (1. / PARB));
}

/**************************************************************************/
/*!
  @brief  Get the corrected resistance RZero of the sensor for calibration
        purposes

  @param[in] t  The ambient air temperature
  @param[in] h  The relative humidity

  @return The corrected sensor resistance RZero in kOhm
*/
/**************************************************************************/
float getCorrectedRZero(float t, float h) {
  return getCorrectedResistance(t, h) * pow((ATMOCO2 / PARA), (1. / PARB));
}
//-----------------------------------------------------------------------------------------------------MQ135^
